@@ -1,4 +1,5 @@
-from typing import Type, List, cast
+from typing import Type, List, cast, Optional
+
 from collections_extended import RangeMap
 from pydantic import BaseModel, Field
 from pymultirole_plugins.v1.processor import ProcessorBase, ProcessorParameters
@@ -9,24 +10,25 @@ class ReadingGridParameters(ProcessorParameters):
     separator: str = Field(
         "", description="Separator to append to the remaining sentences"
     )
-    min_annotations: int = Field(
-        1,
-        description="The minimum number of annotations required to keep the sentence.",
-    )
+    keep: bool = Field(True,
+                       description="If checked, keep the sentence if it contains one of the labels. if not remove it.")
+    labels: Optional[List[str]] = Field(None,
+                                        description="Keep/remove the sentence if it contains one of these labels.",
+                                        extra="label")
     as_altText: str = Field(
         None,
-        description="""If defined generate the summary as an alternative text of the input document,
+        description="""If defined generate the output as an alternative text of the input document,
     if not replace the text of the input document.""",
     )
 
 
 class ReadingGridProcessor(ProcessorBase):
-    """ "A processor that generate a reduced/focussed version of the document keeping only the sentences
-    that actually contain annotations.
+    """ "A processor that generate a reduced/focussed version of the document filtering somes sentences according to
+    their annotations
     """
 
     def process(
-        self, documents: List[Document], parameters: ProcessorParameters
+            self, documents: List[Document], parameters: ProcessorParameters
     ) -> List[Document]:
         params: ReadingGridParameters = cast(ReadingGridParameters, parameters)
         for document in documents:
@@ -35,6 +37,7 @@ class ReadingGridProcessor(ProcessorBase):
             start = 0
             text = ""
             separator = params.separator
+            labels = params.labels or None
             use_altText = params.as_altText is not None and len(params.as_altText) > 0
             if not separator.startswith("\n"):
                 separator = "\n" + separator
@@ -44,16 +47,17 @@ class ReadingGridProcessor(ProcessorBase):
                 sentence_map = RangeMap()
                 for s in document.sentences:
                     if s.end > s.start:
-                        sentence_map[s.start : s.end] = []
+                        sentence_map[s.start: s.end] = []
                 for a in document.annotations:
                     sentence_map[a.start].append(a)
                 for sent in sentence_map.ranges():
                     ann_list = sent.value
-                    if ann_list and len(ann_list) >= params.min_annotations:
+                    keep = keep_or_remove(ann_list, labels, params.keep)
+                    if keep:
                         sstart = start
                         send = sstart + (sent.stop - sent.start)
                         sentences.append(Sentence(start=sstart, end=send))
-                        text += document.text[sent.start : sent.stop] + separator
+                        text += document.text[sent.start: sent.stop] + separator
                         if not use_altText:
                             for a in ann_list:
                                 astart = a.start - sent.start
@@ -80,3 +84,13 @@ class ReadingGridProcessor(ProcessorBase):
     @classmethod
     def get_model(cls) -> Type[BaseModel]:
         return ReadingGridParameters
+
+
+def keep_or_remove(ann_list, labels, keep):
+    if labels is not None and len(labels) > 0:
+        anns = [a for a in ann_list if a.labelName in labels]
+        if len(anns) >= 1:
+            return keep
+        else:
+            return not keep
+    return len(ann_list) >= 1
